import React from "react";
import styled from "styled-components";
import { NavLink } from "react-router-dom";
import { GoogleLogin } from "react-google-login";

const clientID =
  "578412719010-kunrheea50ajh6vi4ruhncf1ps8keebu.apps.googleusercontent.com";

export default function Login() {
  const onFailure = (res) => {
    alert("Failed login");
  };

  const onSuccess = async (res) => {
    console.log(`[Login Success] currentUser:`, res);

    const { email, name, imageUrl } = res.profileObj;
    const data = {
      email,
      name,
      imageUrl,
    };
  };

  return (
    <Container>
      <a href="/">
        <i className="fas fa-arrow-left"></i>
        Go Back
      </a>
      <header>
        <img src="/images/logo.svg" className="logo" alt="Rocketmeme logo" />
        <h2>Rocket Sign In</h2>
        <p>Sign in to see your favourite memes and downloads</p>

        {/* <GitlabAuth className="button" href="/">
          <i className="fab fa-gitlab"></i> Continue with GitLab
          </GitlabAuth>
          <BitbucketAuth className="button" href="/">
          <i className="fab fa-bitbucket"></i> Continue with Bitbucket
         </BitbucketAuth> */}
        <GoogleLogin
          clientId={clientID}
          buttonText="Login"
          onSuccess={onSuccess}
          onFailure={onFailure}
          cookiePolicy={"single_host_origin"}
          render={(renderProps) => (
            // <button
            //   className="createGoogle"
            //   onClick={renderProps.onClick}
            //   // disabled={renderProps.disabled}
            // >
            //   {" "}
            //   Sign in with Google
            // </button>
            <GmailAuth className="button" onClick={renderProps.onClick}>
              <img
                src="/images/google.svg"
                className="gicon"
                alt="Google Icon"
                width="17px"
              />
              Continue with Google
            </GmailAuth>
          )}
          isSignedIn={true}
        />
        <GithubAuth className="button" href="/">
          <i className="fab fa-github"></i> Continue with GitHub
        </GithubAuth>

        <p>
          Don't have an account?
          <NavLink className="signup" to="/SignUp">
            Sign Up
          </NavLink>
        </p>
      </header>
    </Container>
  );
}

const Container = styled.main`
  margin: 2.5rem 0 0;
  display: flex;
  flex-direction: column-reverse;
  align-items: center;
  justify-content: center;
  text-align: center;
  min-height: 100vh;
  background-color: #fff68d;
  background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='100%25' height='100%25' viewBox='0 0 1600 800'%3E%3Cg %3E%3Cpath fill='%23fff8a4' d='M486 705.8c-109.3-21.8-223.4-32.2-335.3-19.4C99.5 692.1 49 703 0 719.8V800h843.8c-115.9-33.2-230.8-68.1-347.6-92.2C492.8 707.1 489.4 706.5 486 705.8z'/%3E%3Cpath fill='%23fff9bb' d='M1600 0H0v719.8c49-16.8 99.5-27.8 150.7-33.5c111.9-12.7 226-2.4 335.3 19.4c3.4 0.7 6.8 1.4 10.2 2c116.8 24 231.7 59 347.6 92.2H1600V0z'/%3E%3Cpath fill='%23fffbd2' d='M478.4 581c3.2 0.8 6.4 1.7 9.5 2.5c196.2 52.5 388.7 133.5 593.5 176.6c174.2 36.6 349.5 29.2 518.6-10.2V0H0v574.9c52.3-17.6 106.5-27.7 161.1-30.9C268.4 537.4 375.7 554.2 478.4 581z'/%3E%3Cpath fill='%23fffde9' d='M0 0v429.4c55.6-18.4 113.5-27.3 171.4-27.7c102.8-0.8 203.2 22.7 299.3 54.5c3 1 5.9 2 8.9 3c183.6 62 365.7 146.1 562.4 192.1c186.7 43.7 376.3 34.4 557.9-12.6V0H0z'/%3E%3Cpath fill='%23FFFFFF' d='M181.8 259.4c98.2 6 191.9 35.2 281.3 72.1c2.8 1.1 5.5 2.3 8.3 3.4c171 71.6 342.7 158.5 531.3 207.7c198.8 51.8 403.4 40.8 597.3-14.8V0H0v283.2C59 263.6 120.6 255.7 181.8 259.4z'/%3E%3Cpath fill='%23ffffff' d='M1600 0H0v136.3c62.3-20.9 127.7-27.5 192.2-19.2c93.6 12.1 180.5 47.7 263.3 89.6c2.6 1.3 5.1 2.6 7.7 3.9c158.4 81.1 319.7 170.9 500.3 223.2c210.5 61 430.8 49 636.6-16.6V0z'/%3E%3Cpath fill='%23ffffff' d='M454.9 86.3C600.7 177 751.6 269.3 924.1 325c208.6 67.4 431.3 60.8 637.9-5.3c12.8-4.1 25.4-8.4 38.1-12.9V0H288.1c56 21.3 108.7 50.6 159.7 82C450.2 83.4 452.5 84.9 454.9 86.3z'/%3E%3Cpath fill='%23ffffff' d='M1600 0H498c118.1 85.8 243.5 164.5 386.8 216.2c191.8 69.2 400 74.7 595 21.1c40.8-11.2 81.1-25.2 120.3-41.7V0z'/%3E%3Cpath fill='%23ffffff' d='M1397.5 154.8c47.2-10.6 93.6-25.3 138.6-43.8c21.7-8.9 43-18.8 63.9-29.5V0H643.4c62.9 41.7 129.7 78.2 202.1 107.4C1020.4 178.1 1214.2 196.1 1397.5 154.8z'/%3E%3Cpath fill='%23FFFFFF' d='M1315.3 72.4c75.3-12.6 148.9-37.1 216.8-72.4h-723C966.8 71 1144.7 101 1315.3 72.4z'/%3E%3C/g%3E%3C/svg%3E");
  background-attachment: fixed;
  background-size: cover;

  @media (max-width: 500px) {
    background: var(--bg-light);
  }

  & > a {
    margin-top: 1rem;
    color: var(--dark-grey);
    transition: 0.2s ease-in-out;

    &:hover {
      color: inherit;
      color: var(--bg-dark);
    }

    i {
      margin-right: 0.3rem;
    }
  }

  header {
    padding: 3rem 2rem;
    background: var(--bg-light);
    border: 1px solid #eee;
    border-radius: 5px;

    .logo {
      margin-bottom: 1rem;
    }

    .button {
      display: flex;
      align-items: center;
      justify-content: center;
      padding: 0.7rem;
      margin: 0.7rem 0;
      border-radius: 3px;
      font-size: 0.95rem;
      width: 100%;

      i,
      img {
        margin-right: 1rem;
      }
    }

    h2 {
      font-size: 1.7rem;
      font-weight: 500;
    }

    p {
      font-size: 0.75rem;
      color: var(--dark-grey);
      padding: 0.3rem 0 1rem;
    }

    .logo {
      width: 45px;
    }

    .signup {
      margin-left: 0.3rem;
      color: var(--primary-color);
    }
  }
`;

const GithubAuth = styled.a`
  background: #23262ee5;
  color: var(--bg-light);
`;
const GitlabAuth = styled.a`
  background: #6753b5;
  color: var(--bg-light);
`;
const BitbucketAuth = styled.a`
  background: #1e54c5e5;
  color: var(--bg-light);
`;
const GmailAuth = styled.a`
  border: var(--border-light);
  background: var(--bg-light);
`;
